@@ -36,6 +36,7 @@ eos
         is_expected.to_not contain_file('/etclibvirt/qemu/networks/autostart/default.xml')
         is_expected.to_not contain_file('/etclibvirt/qemu/networks/default.xml')
         is_expected.to_not contain_exec('libvirt-default-net-destroy')
+        is_expected.to_not contain_exec('set libvirt sasl credentials')
       }
     end
 
@@ -76,6 +77,12 @@ eos
           "unix_sock_ro_perms" => {"value" => '"0777"'},
           "unix_sock_rw_perms" => {"value" => '"0770"'}
         })
+        is_expected.to contain_package('cyrus-sasl-scram')
+        is_expected.to contain_file('/etc/sasl2/libvirt.conf')
+        is_expected.to contain_file('/etc/libvirt/auth.conf').with_ensure('absent')
+        is_expected.to contain_exec('set libvirt sasl credentials').with_command(
+          'saslpasswd2 -d -a libvirt -u overcloud migration'
+        )
       }
     end
 
@@ -114,6 +121,58 @@ eos
           "unix_sock_ro_perms" => {"value" => '"0777"'},
           "unix_sock_rw_perms" => {"value" => '"0770"'}
         })
+        is_expected.to contain_package('cyrus-sasl-scram')
+        is_expected.to contain_file('/etc/sasl2/libvirt.conf')
+        is_expected.to contain_file('/etc/libvirt/auth.conf').with_ensure('absent')
+        is_expected.to contain_exec('set libvirt sasl credentials').with_command(
+          'saslpasswd2 -d -a libvirt -u overcloud migration'
+        )
+      }
+    end
+
+    context 'with step 4 and tls_password' do
+      let(:pre_condition) do
+        <<-eos
+        class { '::tripleo::profile::base::nova':
+          step => #{params[:step]},
+          oslomsg_rpc_hosts => [ '127.0.0.1' ],
+        }
+        class { '::tripleo::profile::base::nova::migration':
+          step => #{params[:step]}
+        }
+        class { '::tripleo::profile::base::nova::migration::client':
+          step => #{params[:step]}
+        }
+        class { '::tripleo::profile::base::nova::compute_libvirt_shared':
+          step => #{params[:step]}
+        }
+eos
+      end
+
+      let(:params) { { :step => 4, :tls_password => 'foo'} }
+
+      it {
+        is_expected.to contain_class('tripleo::profile::base::nova::libvirt')
+        is_expected.to contain_class('tripleo::profile::base::nova::compute_libvirt_shared')
+        is_expected.to contain_class('tripleo::profile::base::nova')
+        is_expected.to contain_class('nova::compute::libvirt::services')
+        is_expected.to contain_class('nova::compute::libvirt::qemu')
+        is_expected.to contain_file('/etc/libvirt/qemu/networks/autostart/default.xml').with_ensure('absent')
+        is_expected.to contain_file('/etc/libvirt/qemu/networks/default.xml').with_ensure('absent')
+        is_expected.to contain_exec('libvirt-default-net-destroy')
+        is_expected.to contain_class('nova::compute::libvirt::config').with_libvirtd_config({
+          "unix_sock_group"    => {"value" => '"libvirt"'},
+          "auth_unix_ro"       => {"value" => '"none"'},
+          "auth_unix_rw"       => {"value" => '"none"'},
+          "unix_sock_ro_perms" => {"value" => '"0777"'},
+          "unix_sock_rw_perms" => {"value" => '"0770"'}
+        })
+        is_expected.to contain_package('cyrus-sasl-scram')
+        is_expected.to contain_file('/etc/sasl2/libvirt.conf')
+        is_expected.to contain_file('/etc/libvirt/auth.conf').with_ensure('present')
+        is_expected.to contain_exec('set libvirt sasl credentials').with_command(
+          "echo \"\${TLS_PASSWORD}\" | saslpasswd2 -p -a libvirt -u overcloud migration"
+        )
       }
     end
   end
